# Study: FW_CCI_10_4
#
# Revision 10 by Joe Pichette
# Revision 10_3 by David Habisohn
# Revision 10_4 by David Habisohn
#
# Revision history:
# Rev# Date Change Description
# ---- --------- ------------------
# 09 2010-11-09 Added signals for CCI20 crossing in and out of zoom
#  10 2011-4-28
#Added signals for CCI20 breaking the 150
#
# 10_3 2011-5-05 Added alerts for CCI20 crossing out of super zoom,
#all snap-back flags default on with Line_vs_Points Cherries, Apples
#and Grapes. Pinky arrow over Yellow arrow.  10_4 2011-5-25
#Changed Grapes to Blueberries and color now user changeable.
#
# Originally developed by ToS User: davidinc (studiessupport@pc3i.com) For
# technical support email or logon to www.pc3i.com   Thanks.
#
declare lower;

input showBreadth_05_50 = no;
input showFlag_05_50 = yes;
input showBreadth_20_50 = no;
input showFlag_20_50 = yes;
input showBreadth_05_20 = no;
input showFlag_05_20 = yes;
input showFlag_SuperSnap = yes; 

# CCI50 in zoom zone & CCI05 in opposite zoom zone. 

input SuperSnap_Offset = 0;

# increase when arrow flags plot off the graph 

input showFlag_100_Trans = yes; 

# flags movement of CCI50 thru the +100 / -100 lines. 

input showFlag_150_Trans = yes; 

# flags movement of CCI20 thru the +150 / -150 lines. 

input ShowZoomAlerts = no;

# must be yes for audio or visual alerts 

input AlertSoundType = {default "NoSound", "Bell", "Chimes", "Ding", "Ring"};

def length05 = 5;
def length20 = 20;
def length50 = 50;
def price = (high + low + close);
def linDev05 = lindev(price, length05);
def linDev20 = lindev(price, length20);
def linDev50 = lindev(price, length50);

# plot the horizontal reference lines first so they are underneath. 

plot OverBought = +100;
Overbought.SetDefaultColor(Color.Light_Red);
Overbought.HideBubble();

plot ZeroLine = 0;
ZeroLine.SetDefaultColor(Color.Dark_Green);
ZeroLine.SetStyle(Curve.Short_Dash);
ZeroLine.HideBubble();
 
plot OverSold = -100;
Oversold.SetDefaultColor(Color.Light_Red);
Oversold.HideBubble();
 
plot BreadthLo = if showBreadth_05_50 or showBreadth_05_20 or showBreadth_20_50 or showFlag_05_50 or showFlag_05_20 or showFlag_20_50 then -150 else double.nan;

BreadthLo.SetDefaultColor(Color.Gray);
BreadthLo.HideBubble();
 
plot BreadthHi = if showBreadth_05_50 or showBreadth_05_20 or  showBreadth_20_50 or showFlag_05_50 or showFlag_05_20 or showFlag_20_50 then +150 else double.nan;

BreadthHi.SetDefaultColor(Color.Gray);
BreadthHi.HideBubble();

# actual CCI plots start here 

plot CCI50 = if linDev50 == 0 then 0 else
(price - Average(price, length50)) / linDev50 / 0.015;
CCI50.SetDefaultColor(Color.Cyan);
 
plot CCI20 = if linDev20 == 0
then 0 else (price - Average(price, length20)) / linDev20 / 0.015;

CCI20.SetDefaultColor(Color.Yellow);
 
plot CCI05 = if linDev05 == 0
then 0 else (price - Average(price, length05)) / linDev05 / 0.015;

CCI05.SetDefaultColor(Color.White);

# these are the 3 breadth plots 

def Diff_05_50 = CCI05 - CCI50;

plot CCI_Breadth_05_50 = if showBreadth_05_50 
    then Diff_05_50 else double.nan;

CCI_Breadth_05_50.SetDefaultColor(Color.Red);
CCI_Breadth_05_50.SetStyle(Curve.Short_Dash);
 
def Diff_20_50 = CCI20 - CCI50;

plot CCI_Breadth_20_50 = if showBreadth_20_50 then Diff_20_50 else double.nan;

CCI_Breadth_20_50.SetDefaultColor(Color.Green);
CCI_Breadth_20_50.SetStyle(Curve.Short_Dash);
 
def Diff_05_20 = CCI05 - CCI20;

plot CCI_Breadth_05_20 = if showBreadth_05_20 then     Diff_05_20 else double.nan;

CCI_Breadth_05_20.SetDefaultColor(Color.Blue);
CCI_Breadth_05_20.SetStyle(Curve.Short_Dash);

# these are the flag plots

plot Flag_05_50_Up = if showFlag_05_50 and Diff_05_50 > 150 then Diff_05_50 else double.nan;

Flag_05_50_Up.SetDefaultColor(Color.Red);
Flag_05_50_Up.SetPaintingStrategy(PaintingStrategy.Line_vs_Points);
Flag_05_50_Up.HideBubble();

plot Flag_05_50_Dn = if showFlag_05_50
    and Diff_05_50 < -150 then Diff_05_50 else double.nan;

Flag_05_50_Dn.SetDefaultColor(Color.Red);
Flag_05_50_Dn.SetPaintingStrategy(PaintingStrategy.Line_vs_Points);

Flag_05_50_Dn.HideBubble();

plot Flag_20_50_Up = if showFlag_20_50 and Diff_20_50 > 150 
    then Diff_20_50 else double.nan;

Flag_20_50_Up.SetDefaultColor(Color.Green);
Flag_20_50_Up.SetPaintingStrategy(PaintingStrategy.Line_vs_Points);
Flag_20_50_Up.HideBubble();

plot Flag_20_50_Dn = if showFlag_20_50 and Diff_20_50 < -150 
    then Diff_20_50 else double.nan;

Flag_20_50_Dn.SetDefaultColor(Color.Green);
Flag_20_50_Dn.SetPaintingStrategy(PaintingStrategy.Line_vs_Points);
Flag_20_50_Dn.HideBubble();

plot Flag_05_20_Up = if showFlag_05_20 and Diff_05_20 > 150 
    then Diff_05_20 else double.nan;

Flag_05_20_Up.SetDefaultColor(Color.Blue);
Flag_05_20_Up.SetPaintingStrategy(PaintingStrategy.Line_vs_Points);
Flag_05_20_Up.HideBubble();

plot Flag_05_20_Dn = if showFlag_05_20 and Diff_05_20 < -150 
    then Diff_05_20 else double.nan;

Flag_05_20_Dn.SetDefaultColor(Color.Blue);
Flag_05_20_Dn.SetPaintingStrategy(PaintingStrategy.Line_vs_Points);
Flag_05_20_Dn.HideBubble();

plot ScaleUp = 

# this dot is used to force better scaling of the arrow  

if showFlag_SuperSnap and CCI50 >= +100 and CCI05 <= -100 
    then Diff_05_50 - 50 - SuperSnap_Offset 
    else double.nan;

ScaleUp.SetDefaultColor(Color.Black);
ScaleUp.SetPaintingStrategy(PaintingStrategy.Points);
ScaleUp.HideBubble();

plot SuperSnapUp =  

if showFlag_SuperSnap and CCI50 >= +100 and CCI05 <= -100 
    then Diff_05_50 - 20 
    else double.nan;

SuperSnapUp.SetDefaultColor(Color.Cyan);
SuperSnapUp.SetPaintingStrategy(PaintingStrategy.Arrow_Up);
SuperSnapUp.SetLineWeight(3);
SuperSnapUp.HideBubble();

# this dot is used to force better scaling of the arrow  

plot ScaleDn =

if showFlag_SuperSnap and CCI50 <= -100 and CCI05 >= +100 then Diff_05_50 + 50 + SuperSnap_Offset else double.nan;

ScaleDn.SetDefaultColor(Color.Black);
ScaleDn.SetPaintingStrategy(PaintingStrategy.Points);
ScaleDn.HideBubble();

plot SuperSnapDn = 

if showFlag_SuperSnap and CCI50 <= -100 and CCI05 >= +100 then Diff_05_50 + 20 else double.nan;

SuperSnapDn.SetDefaultColor(Color.Yellow);
SuperSnapDn.SetPaintingStrategy(PaintingStrategy.Arrow_Down);
SuperSnapDn.SetLineWeight(3);
SuperSnapDn.HideBubble();

# Code for this section provided by Adam Green 

def OverBought150 = +150;
def Oversold150   = -150;

plot CCI20TransUp150 =  

if showFlag_150_Trans then if (CCI20 >= Oversold150 && CCI20[1] < Oversold150) then CCI20 else double.nan else double.nan;

CCI20TransUp150.SetDefaultColor(Color.Magenta);
CCI20TransUp150.SetPaintingStrategy(PaintingStrategy.Arrow_Up);
CCI20TransUp150.SetLineWeight(2);
CCI20TransUp150.HideBubble();

plot CCI20TransDn150 = 

if showFlag_150_Trans then if (CCI20 <= Overbought150 && CCI20[1] > Overbought150)then CCI20 else double.nan else double.nan;

CCI20TransDn150.SetDefaultColor(Color.Magenta);
CCI20TransDn150.SetPaintingStrategy(PaintingStrategy.Arrow_Down);
CCI20TransDn150.SetLineWeight(2);
CCI20TransDn150.HideBubble();

plot CCI50TransUp = 

if showFlag_100_Trans then if (CCI50 >= Overbought && CCI50[1] < Overbought) or (CCI50 >= Oversold && CCI50[1] < Oversold) then CCI50 else double.nan else double.nan;

CCI50TransUp.SetDefaultColor(Color.Green);
CCI50TransUp.SetPaintingStrategy(PaintingStrategy.Arrow_Up);
CCI50TransUp.SetLineWeight(3);
CCI50TransUp.HideBubble();
 
plot CCI50TransDn = 

if showFlag_100_Trans 
    then if (CCI50 <= Overbought && CCI50[1] > Overbought) or (CCI50 <= Oversold && CCI50[1] > Oversold) then CCI50 else double.nan else double.nan;

CCI50TransDn.SetDefaultColor(Color.Red);
CCI50TransDn.SetPaintingStrategy(PaintingStrategy.Arrow_Down);
CCI50TransDn.SetLineWeight(3);
CCI50TransDn.HideBubble();

plot CCI20TransUp = 

if showFlag_100_Trans then if (CCI20 >= Overbought && CCI20[1] < Overbought) or (CCI20 >= Oversold && CCI20[1] < Oversold) then CCI20 else double.nan else double.nan;

CCI20TransUp.SetDefaultColor(Color.Yellow);
CCI20TransUp.SetPaintingStrategy(PaintingStrategy.Arrow_Up);
CCI20TransUp.SetLineWeight(3);
CCI20TransUp.HideBubble();

plot CCI20TransDn = 

if showFlag_100_Trans then if (CCI20 <= Overbought && CCI20[1] > Overbought) or (CCI20 <= Oversold && CCI20[1] > Oversold) then CCI20 else double.nan else double.nan;

CCI20TransDn.SetDefaultColor(Color.Yellow);
CCI20TransDn.SetPaintingStrategy(PaintingStrategy.Arrow_Down);
CCI20TransDn.SetLineWeight(3);
CCI20TransDn.HideBubble();

# Add Alerts for CCI50 transitioning into or out of +100 or -100 zoom zones. 

alert (ShowZoomAlerts #into the ZOOM UP zone  
    and (CCI50[1] >= Overbought && CCI50[2] < Overbought),
   "CCI50ZoomUP", Alert.Bar, AlertSoundType);

alert (ShowZoomAlerts # out of the ZOOM UP zone 
    and (CCI50[1] <= Overbought && CCI50[2] > Overbought),
   "CCI50ZoomUP-NOT", Alert.Bar, AlertSoundType);

alert (ShowZoomAlerts # into the ZOOM DOWN zone 
   and (CCI50[1] <= OverSold && CCI50[2] > OverSold),
   "CCI50ZoomDOWN", Alert.Bar, AlertSoundType);

alert (ShowZoomAlerts # out of the ZOOM DOWN zone
   and (CCI50[1] >= OverSold && CCI50[2] < OverSold), 
    "CCI50ZoomDOWN-NOT", Alert.Bar, AlertSoundType); 

# Add Alerts for CCI20 transitioning out of +150 or -150 super zoom zones by David Habisohn 

alert (ShowZoomAlerts # out of the ZOOM UP zone
   and (CCI20[1] <= Overbought150 && CCI20[2] > Overbought150),
   "CCI20DownFromSuperZoom", Alert.Bar, AlertSoundType);

alert (ShowZoomAlerts # out of the ZOOM DOWN zone
  and (CCI20[1] >= OverSold150 && CCI20[2] < OverSold150), 
    "CCI20UpFromSuperZoom", Alert.Bar, AlertSoundType);